@@ -3,6 +3,21 @@ package Test::Mock::Cmd::TestUtils;
 use strict;
 use warnings;
 
+sub do_in_fork {
+    my ( $code, @args ) = @_;
+    my $pid = fork();
+    if ( not defined $pid ) {
+        die "Could not fork: $!";
+    }
+    elsif ( $pid == 0 ) {
+        $code->(@args);
+        exit 1;
+    }
+    else {
+        waitpid( $pid, 0 );    # parent
+    }
+}
+
 sub test_more_is_like_return_42 {
     my ( $got, $expected, $name ) = @_;
     ref($expected) eq 'Regexp' ? Test::More::like( $got, $expected, $name ) : Test::More::is( $got, $expected, $name );
@@ -10,6 +25,7 @@ sub test_more_is_like_return_42 {
 }
 
 # use Test::Output; # rt 72976
+# The Perl::Critic test failures will go away when this temp workaround goes away
 sub tmp_stdout_like_rt_72976 {
     my ( $func, $regex, $name ) = @_;
     my $output = '';
@@ -28,7 +44,12 @@ sub tmp_stdout_like_rt_72976 {
         $func->();
         open STDOUT, '>&OLDOUT' or die "Could not restore STDOUT: $!";
 
-        chomp( $output = `cat tmp.$$.tmp` );
+        open my $fh, '<', "tmp.$$.tmp" or die "Could not open temp file: $!";
+        while ( my $line = <$fh> ) {
+            $output .= $line;
+        }
+        close $fh;
+
         unlink "tmp.$$.tmp";
     }
 
